@@ -3,9 +3,9 @@ package reader
 import (
 	"regexp"
 
-	"github.com/walles/moor/internal/linemetadata"
-	"github.com/walles/moor/internal/textstyles"
-	"github.com/walles/moor/twin"
+	"github.com/walles/moor/v2/internal/linemetadata"
+	"github.com/walles/moor/v2/internal/textstyles"
+	"github.com/walles/moor/v2/twin"
 )
 
 type NumberedLine struct {
